@@ -8,7 +8,7 @@ from . import compare_html
 
 __all__ = ['assert_different_html', 'assert_same_html']
 
-def stringify_token_to_str(token):
+def stringify_token(token):
     if token['type'] in ('StartTag', 'EmptyTag'):
         attrs = []
         for attr_key, attr_value in token['data'].items():
@@ -16,6 +16,10 @@ def stringify_token_to_str(token):
             attrs.append('%s="%s"' % (key, attr_value))
         attr_str = (' ' if attrs else '') + ' '.join(attrs)
         return '<%s%s>' % (token["name"], attr_str)
+    elif token['type'] == 'EndTag':
+        return '</%s>' % (token["name"], )
+    elif token['type'] == 'Characters':
+        return '%s' % token['data']
     raise NotImplementedError(token['type'])
 
 def assert_same_html(expected_html, actual_html, verbose=True):
@@ -23,8 +27,8 @@ def assert_same_html(expected_html, actual_html, verbose=True):
     if result:
         return
     diff = result.differences[0]
-    expected_str = stringify_token_to_str(diff.expected)
-    actual_str = stringify_token_to_str(diff.actual)
+    expected_str = stringify_token(diff.expected)
+    actual_str = stringify_token(diff.actual)
     if verbose:
         print('-' + expected_str)
         print('+' + actual_str)
